==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Barycentric_coordinates_2/group__PkgBarycentricCoordinates2RefHarmonic.js <==
var group__PkgBarycentricCoordinates2RefHarmonic =
[
    [ "Delaunay_domain_2", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html", [
      [ "FT", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a151c171af7b57645edea12d34b9c82dc", null ],
      [ "Point_2", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a6584d8be65aeec83b341e1f8fe7db754", null ],
      [ "Delaunay_domain_2", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#aace47621de34bc474ec1199098042c1f", null ],
      [ "barycenters", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a6f326b5d2ad2ad8e9da3ca22a7e49c8b", null ],
      [ "clear", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#ae249e61cae6650d81e93136cc3ff906c", null ],
      [ "create", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a527c4b3761bf4712534b7ac043c0c705", null ],
      [ "is_on_boundary", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a7068961f8c76d442d9722b69885e0d12", null ],
      [ "locate", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#ada4ad037e86d42e5276b462f9a2e4d40", null ],
      [ "number_of_vertices", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a1f7041754225dea234335bd9a9464ac2", null ],
      [ "operator()", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#ae8c0cfaa05eab04f7fcebe5a769c1370", null ],
      [ "release_memory", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#aa1c879bba1cfe8d18cd736d05c80f555", null ],
      [ "vertex", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#ae38708e94e0271fb33e202d8e9d98c0e", null ]
    ] ],
    [ "Harmonic_coordinates_2", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html", [
      [ "FT", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#afa9762d53bb7746b113f51060eccf1b9", null ],
      [ "Point_2", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#a1f1fe1d33e5e712f927a3c58df55fb9c", null ],
      [ "Harmonic_coordinates_2", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#ad35a963443b2b0234e664e79f07f8303", null ],
      [ "clear", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#ac709e2d369f967fed6fa81a82e3f2a21", null ],
      [ "compute", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#ae4ae4f4146cc5edaf44a239975567b65", null ],
      [ "factorize", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#af6ccf6708af665e5c23444bb5a60075c", null ],
      [ "operator()", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#a9004b7480eb1c3a23c4b01650d4c9a2d", null ],
      [ "operator()", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#a091e7996bafb41a7165b45ac550b8573", null ],
      [ "operator()", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#ad5acb7c39bcccd3dbcd831768841b36c", null ],
      [ "release_memory", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#af122383af5461ea82fd27f8c68247495", null ],
      [ "setup", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#ae141cd33853148ea04effea8f6c58b25", null ],
      [ "solve", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#a16825c147fabf7f894f2fb5434140e6f", null ]
    ] ]
];

==> CGAL-6.0.3-doc_html.tar.xz: doc_html/Barycentric_coordinates_2/group__PkgBarycentricCoordinates2RefHarmonic.js <==
var group__PkgBarycentricCoordinates2RefHarmonic =
[
    [ "CGAL::Barycentric_coordinates::Delaunay_domain_2< VertexRange, GeomTraits, PointMap >", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html", [
      [ "FT", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a151c171af7b57645edea12d34b9c82dc", null ],
      [ "Point_2", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a6584d8be65aeec83b341e1f8fe7db754", null ],
      [ "Delaunay_domain_2", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#aace47621de34bc474ec1199098042c1f", null ],
      [ "barycenters", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a6f326b5d2ad2ad8e9da3ca22a7e49c8b", null ],
      [ "clear", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#ae249e61cae6650d81e93136cc3ff906c", null ],
      [ "create", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a527c4b3761bf4712534b7ac043c0c705", null ],
      [ "is_on_boundary", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a7068961f8c76d442d9722b69885e0d12", null ],
      [ "locate", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#ada4ad037e86d42e5276b462f9a2e4d40", null ],
      [ "number_of_vertices", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a1f7041754225dea234335bd9a9464ac2", null ],
      [ "operator()", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#ae8c0cfaa05eab04f7fcebe5a769c1370", null ],
      [ "release_memory", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#aa1c879bba1cfe8d18cd736d05c80f555", null ],
      [ "vertex", "classCGAL_1_1Barycentric__coordinates_1_1Delaunay__domain__2.html#a1b45d0910604c255ab190a953ca901ff", null ]
    ] ],
    [ "CGAL::Barycentric_coordinates::Harmonic_coordinates_2< VertexRange, DiscretizedDomain, GeomTraits, PointMap >", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html", [
      [ "FT", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#afa9762d53bb7746b113f51060eccf1b9", null ],
      [ "Point_2", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#a1f1fe1d33e5e712f927a3c58df55fb9c", null ],
      [ "Harmonic_coordinates_2", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#ad35a963443b2b0234e664e79f07f8303", null ],
      [ "clear", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#ac709e2d369f967fed6fa81a82e3f2a21", null ],
      [ "compute", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#ae4ae4f4146cc5edaf44a239975567b65", null ],
      [ "factorize", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#af6ccf6708af665e5c23444bb5a60075c", null ],
      [ "operator()", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#a9004b7480eb1c3a23c4b01650d4c9a2d", null ],
      [ "operator()", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#a091e7996bafb41a7165b45ac550b8573", null ],
      [ "operator()", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#ad5acb7c39bcccd3dbcd831768841b36c", null ],
      [ "release_memory", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#af122383af5461ea82fd27f8c68247495", null ],
      [ "setup", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#ae141cd33853148ea04effea8f6c58b25", null ],
      [ "solve", "classCGAL_1_1Barycentric__coordinates_1_1Harmonic__coordinates__2.html#a16825c147fabf7f894f2fb5434140e6f", null ]
    ] ]
];
